AtActivateApiClient class

Dart API client for the at_activate_web HTTP API.

Constructors

AtActivateApiClient({required Uri baseUri, HttpClient? httpClient})

Properties

baseUri Uri
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approveEnrollment(String enrollmentId) Future<ApiActionResult>
checkOnboarding() Future<OnboardingCheckResponse>
close() → void
deleteEnrollment(String enrollmentId) Future<ApiActionResult>
denyEnrollment(String enrollmentId) Future<ApiActionResult>
getEnrollments() Future<EnrollmentsResponse>
getOtp() Future<String>
listAtSigns() Future<List<AtSignInfo>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revokeEnrollment(String enrollmentId) Future<ApiActionResult>
selectAtSign(String atsign) Future<Map<String, dynamic>>
shutdown() Future<Map<String, dynamic>>
subscribeEvents() Stream<SseEvent>
Opens /api/events and emits decoded SSE data payloads.
toString() String
A string representation of this object.
inherited
unrevokeEnrollment(String enrollmentId) Future<ApiActionResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited