EnrollmentDto class

Constructors

EnrollmentDto({required String enrollmentId, required String appName, required String deviceName, required String namespace, required String status, required Map<String, dynamic> apkamKeys})
EnrollmentDto.fromJson(Map<String, dynamic> json)
factory

Properties

apkamKeys Map<String, dynamic>
final
appName String
final
deviceName String
final
enrollmentId String
final
hashCode int
The hash code for this object.
no setterinherited
namespace String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited