AppConfig class
Constructors
Properties
- atsignPostfix → String
-
final
- atsignPrefix → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- registrarApiKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? registrarApiKey, String? atsignPrefix, String? atsignPostfix}) → AppConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited