ConfigStore class

Constructors

ConfigStore()

Properties

directoryPath String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureReady() Future<void>
load() Future<AppConfig>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(AppConfig config) Future<AppConfig>
toString() String
A string representation of this object.
inherited
update(AppConfig config) Future<AppConfig>
updateRegistrarApiKey(String apiKey) Future<AppConfig>

Operators

operator ==(Object other) bool
The equality operator.
inherited