CramKeyStore class

Constructors

CramKeyStore()

Properties

directoryPath String?
no setter
hashCode int
The hash code for this object.
no setterinherited
oldDirectoryPath String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

archiveCramKey(String atSign) Future<String>
ensureReady() Future<void>
listArchivedCramKeys() Future<List<Map<String, dynamic>>>
listPendingCramKeys() Future<List<Map<String, dynamic>>>
normalizeAtSign(String value) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPendingCramKey(String atSign) Future<Map<String, dynamic>>
saveCramKey({required String atSign, required String cramKey, String? sourceTransactionPath}) Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited