EnrollmentInfo class

Information about an enrollment

Constructors

EnrollmentInfo({required String enrollmentId, required String appName, required String deviceName, required String namespace, required String status, DateTime? requestedDate, DateTime? approvedDate, required Map<String, dynamic> apkamKeys})
EnrollmentInfo.fromEnrollment(Enrollment enrollment, EnrollmentStatus status, Map<String, dynamic> enrichedData)
factory

Properties

apkamKeys Map<String, dynamic>
final
appName String
final
approvedDate DateTime?
final
deviceName String
final
enrollmentId String
final
hashCode int
The hash code for this object.
no setterinherited
namespace String
final
requestedDate DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited