EnrollmentManager class

Manages APKAM enrollment status for an atSign

Constructors

EnrollmentManager(String atSign, String rootDomain, {String? password})

Properties

atSign String
final
hashCode int
The hash code for this object.
no setterinherited
password String?
final
rootDomain String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approveEnrollment(String enrollmentId) Future<void>
Approve an enrollment
deleteEnrollment(String enrollmentId) Future<void>
Delete an enrollment completely
denyEnrollment(String enrollmentId) Future<void>
Deny an enrollment
dispose() Future<void>
Clean up resources including temporary storage
getOtp() Future<String>
Get the current OTP (One-Time Passcode) for enrollment requests
initialize() Future<void>
Initialize the at_client connection
listEnrollments() Future<List<EnrollmentInfo>>
List all enrollments using the official EnrollmentService API
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putOtp(String value) Future<String>
Set a custom OTP (semi-permanent passcode) on the secondary server
revokeEnrollment(String enrollmentId) Future<void>
Revoke an enrollment
toString() String
A string representation of this object.
inherited
unrevokeEnrollment(String enrollmentId) Future<void>
Unrevoke an enrollment

Operators

operator ==(Object other) bool
The equality operator.
inherited