KeyStateStore class

Constructors

KeyStateStore()

Properties

directoryPath String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendHistoryEntry({required String atSign, required String type, required String summary, Map<String, dynamic> data = const <String, dynamic>{}}) Future<Map<String, dynamic>>
appendOtpHistory({required String atSign, required String otp, String expiry = '', String? expiresAtUtc}) Future<Map<String, dynamic>>
ensureReady() Future<void>
listAllStates() Future<List<Map<String, dynamic>>>
loadState(String atSign) Future<Map<String, dynamic>>
mutateState({required String atSign, required void mutate(Map<String, dynamic> state)}) Future<Map<String, dynamic>>
normalizeAtSign(String value) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOtpHistoryEntry({required String atSign, required String otp, required String generatedAtUtc}) Future<Map<String, dynamic>>
saveAutoApprovalServices({required String atSign, required List<Map<String, dynamic>> services}) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited