WebAssets class

Embedded web assets for at_activate_web

Constructors

WebAssets()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

apiV4Js → const String
API v4 console JavaScript code
css → const String
CSS stylesheet
html → const String
HTML index page
js → const String
JavaScript code
landingHtml → const String
Landing page HTML
landingJs → const String
Landing page JavaScript