WizardReportStore class
Constructors
Properties
- directoryPath → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createReport(
{required List< String> requestedAtSigns, required String otpExpiry, required String deviceName, required String appName}) → Future<Map< String, dynamic> > -
ensureReady(
) → Future< void> -
listReports(
) → Future< List< Map< >String, dynamic> > -
loadReport(
String reportId) → Future< Map< String, dynamic> > -
markRunningReportsInterrupted(
) → Future< void> -
mutateReport(
{required String reportId, required void mutate(Map< String, dynamic> report)}) → Future<Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited