history_store library
Classes
- HistoryStore
- Append-only audit log of user operations.
Constants
- historySourceLocal → const String
- Operations performed outside Super API Key land (atSign selection, basic activation, enrollments, OTPs, auto approval services).
- historySourceSuperApiKey → const String
- Operations performed with the Super API Key (registrar calls, wizard runs, CRAM activation, Super API Key config changes).
Functions
-
eventsFromKeyStates(
List< Map< states) → List<String, dynamic> >Map< String, dynamic> > -
Normalizes the per-atSign
history[]arrays into unified history events. -
eventsFromTransactions(
List< Map< transactions) → List<String, dynamic> >Map< String, dynamic> > - Normalizes saved registrar transaction files into unified history events.
-
historyTransactionTypeLabel(
String type) → String - Human readable label for a saved registrar transaction type.
-
sortHistoryEvents(
List< Map< events) → voidString, dynamic> > - Sorts unified history events newest first, in place.