HistoryStore class
Append-only audit log of user operations.
Events are stored as NDJSON (one compact JSON object per line) so that appending an event is a genuine file append instead of a read-modify-write of the whole log. Nothing is ever removed from the log.
Constructors
- HistoryStore({Directory? directory})
Properties
- directoryPath → String?
-
no setter
- filePath → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendEvent(
{required String type, required String source, required String summary, String atSign = '', String status = 'success', Map< String, dynamic> data = const <String, dynamic>{}}) → Future<void> -
ensureReady(
) → Future< void> -
listEvents(
) → Future< List< Map< >String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited